@@ -1,4 +1,4 @@
-#ident "$Id$"
+#ident "$Id: rdmsr.c,v 1.3 2003/01/07 03:07:23 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2000 Transmeta Corporation - All Rights Reserved
@@ -76,7 +76,7 @@ void usage(void)
 	  "  --help         -h  Print this help\n"
 	  "  --version      -V  Print current version\n"
 	  "  --hexadecimal  -x  Hexadecimal output (lower case)\n"
-	  "  --captial-hex  -X  Hexadecimal output (upper case)\n"
+	  "  --capital-hex  -X  Hexadecimal output (upper case)\n"
 	  "  --decimal      -d  Signed decimal output\n"
 	  "  --unsigned     -u  Unsigned decimal output\n"
 	  "  --octal        -o  Octal output\n"
@@ -109,7 +109,7 @@ int main(int argc, char *argv[])
     case 'h':
       usage();
       exit(0);
-    case 'v':
+    case 'V':
       fprintf(stderr, "%s: version %s\n", program, VERSION_STRING);
       exit(0);
     case 'x':
