@@ -1,4 +1,4 @@
-#ident "$Id$"
+#ident "$Id: wrmsr.c,v 1.2 2003/01/07 03:07:23 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2000 Transmeta Corporation - All Rights Reserved
@@ -65,7 +65,7 @@ int main(int argc, char *argv[])
     case 'h':
       usage();
       exit(0);
-    case 'v':
+    case 'V':
       fprintf(stderr, "%s: version %s\n", program, VERSION_STRING);
       exit(0);
     case 'p':
